# Generate devel rpm
%global with_devel 1
# Build project from bundled dependencies
%global with_bundled 0
# Build with debug info rpm
%global with_debug 1
# Run tests in check section
%global with_check 1
# Generate unit-test rpm
%global with_unit_test 1
# We do not build codegen since it aims the generation of extra code and tests
# for new locales. Thus, sources are shipped in the devel subpackage
%global with_codegen 0

%if 0%{?with_debug}
%global _dwz_low_mem_die_limit 0
%else
%global debug_package   %{nil}
%endif

# This is necessary for the debuginfo package
# See https://fedoraproject.org/wiki/PackagingDrafts/Go#Debuginfo for reference
%if ! 0%{?gobuild:1}
%define gobuild(o:) go build -ldflags "${LDFLAGS:-} -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n')" -a -v -x %{?**};
%endif

%global provider        github
%global provider_tld    com
%global project         nicksnyder
%global repo            go-i18n
# https://github.com/nicksnyder/go-i18n
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}
%global git_tag v1.10.0
%global commit          0dc1626d56435e9d605a29875701721c54bc9bbd
%global shortcommit     %(c=%{commit}; echo ${c:0:7})

Name:           go-i18n
Version:        1.10.0
Release:        3%{?dist}
Summary:        Translate Go programs into multiple languages
License:        MIT
URL:            https://%{provider_prefix}
Source0:        https://github.com/%{project}/%{repo}/archive/%{git_tag}/%{name}-%{version}.tar.gz
Patch0:         pr-86-fix-tests-go-1.10.patch

# e.g. el6 has ppc64 arch without gcc-go, so EA tag is required
ExclusiveArch:  %{?go_arches:%{go_arches}}%{!?go_arches:%{ix86} x86_64 aarch64 %{arm}}
# If go_compiler is not set to 1, there is no virtual provide. Use golang instead.
BuildRequires:  %{?go_compiler:compiler(go-compiler)}%{!?go_compiler:golang}

BuildRequires: golang(gopkg.in/yaml.v2)
BuildRequires: golang(github.com/pelletier/go-toml)


%description
%{summary}.

%if 0%{?with_devel}
%package -n golang-%{provider}-%{project}-%{repo}-devel
Summary:       %{summary}
BuildArch:     noarch

Requires:      golang(gopkg.in/yaml.v2)
Requires:      golang(github.com/pelletier/go-toml)

Provides:      golang(%{import_path}/i18n) = %{version}-%{release}
Provides:      golang(%{import_path}/i18n/bundle) = %{version}-%{release}
Provides:      golang(%{import_path}/i18n/language) = %{version}-%{release}
Provides:      golang(%{import_path}/i18n/translation) = %{version}-%{release}

%description -n golang-%{provider}-%{project}-%{repo}-devel
%{summary}

This package contains library source intended for
building other packages which use import path with
%{import_path} prefix.
%endif

%if 0%{?with_unit_test} && 0%{?with_devel}
%package -n golang-%{provider}-%{project}-%{repo}-unit-test-devel
Summary:         Unit tests for %{name} package

# test subpackage tests code from devel subpackage
Requires:        golang-%{provider}-%{project}-%{repo}-devel = %{version}-%{release}


%description -n golang-%{provider}-%{project}-%{repo}-unit-test-devel
%{summary}

This package contains unit tests for project
providing packages with %{import_path} prefix.
%endif

%prep
%autosetup -p1 -n %{repo}-%{version}

%build
mkdir -p src/%{provider}.%{provider_tld}/%{project}
ln -s ../../../ src/%{import_path}

export GOPATH=$(pwd):%{gopath}

%gobuild -o bin/goi18n %{import_path}/goi18n
%if 0%{?with_codegen}
%gobuild -o bin/i18n/language/codegen %{import_path}/i18n/language/codegen
%endif

%install
install -d -p %{buildroot}%{_bindir}
install -p -m 0755 bin/goi18n %{buildroot}%{_bindir}
%if 0%{?with_codegen}
install -p -m 0755 bin/i18n/language/codegen %{buildroot}%{_bindir}
%endif

# source codes for building projects
%if 0%{?with_devel}
install -d -p %{buildroot}/%{gopath}/src/%{import_path}/
echo "%%dir %%{gopath}/src/%%{import_path}/." >> devel.file-list
# find all *.go but no *_test.go files and generate devel.file-list
for file in $(find . \( -iname "*.go" -or -iname "*.s" \) \! -iname "*_test.go" \! -path "./goi18n/testdata/*") ; do
    dirprefix=$(dirname $file)
    install -d -p %{buildroot}/%{gopath}/src/%{import_path}/$dirprefix
    cp -pav $file %{buildroot}/%{gopath}/src/%{import_path}/$file
    echo "%%{gopath}/src/%%{import_path}/$file" >> devel.file-list

    while [ "$dirprefix" != "." ]; do
        echo "%%dir %%{gopath}/src/%%{import_path}/$dirprefix" >> devel.file-list
        dirprefix=$(dirname $dirprefix)
    done
done
%endif

# testing files for this project
%if 0%{?with_unit_test} && 0%{?with_devel}
install -d -p %{buildroot}/%{gopath}/src/%{import_path}/
# find all *_test.go files and generate unit-test-devel.file-list
for file in $(find . -iname "*_test.go") ; do
    dirprefix=$(dirname $file)
    install -d -p %{buildroot}/%{gopath}/src/%{import_path}/$dirprefix
    cp -pav $file %{buildroot}/%{gopath}/src/%{import_path}/$file
    echo "%%{gopath}/src/%%{import_path}/$file" >> unit-test-devel.file-list

    while [ "$dirprefix" != "." ]; do
        echo "%%dir %%{gopath}/src/%%{import_path}/$dirprefix" >> devel.file-list
        dirprefix=$(dirname $dirprefix)
    done
done
# install data used for tests
cp -pav ./goi18n/testdata %{buildroot}/%{gopath}/src/%{import_path}/goi18n/
echo "%%{gopath}/src/%%{import_path}/goi18n/testdata" >> unit-test-devel.file-list

%endif

%if 0%{?with_devel}
sort -u -o devel.file-list devel.file-list
%endif

%check
%if 0%{?with_check} && 0%{?with_unit_test} && 0%{?with_devel}
%if ! 0%{?with_bundled}
export GOPATH=%{buildroot}/%{gopath}:%{gopath}
%else
# No dependency directories so far

export GOPATH=%{buildroot}/%{gopath}:%{gopath}
%endif

%if ! 0%{?gotest:1}
%global gotest go test
%endif

%gotest %{import_path}/goi18n
%gotest %{import_path}/i18n
%gotest %{import_path}/i18n/bundle
%gotest %{import_path}/i18n/language
%gotest %{import_path}/i18n/translation
%endif

#define license tag if not already defined
%{!?_licensedir:%global license %doc}

%files
%license LICENSE
%doc README.md
%{_bindir}/goi18n
%if 0%{?with_codegen}
%{_bindir}/i18n/language/codegen
%endif

%if 0%{?with_devel}
%files -n golang-%{provider}-%{project}-%{repo}-devel -f devel.file-list
%license LICENSE
%doc README.md
%dir %{gopath}/src/%{provider}.%{provider_tld}/%{project}
%endif

%if 0%{?with_unit_test} && 0%{?with_devel}
%files -n golang-%{provider}-%{project}-%{repo}-unit-test-devel -f unit-test-devel.file-list
%license LICENSE
%doc README.md
%endif

%changelog
* Mon Feb 19 2018 Athos Ribeiro <athoscr@fedoraproject.org> - 1.10.0-3
- Fix tests with https://github.com/nicksnyder/go-i18n/pull/86 patch

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.10.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Mon Nov 20 2017 Athos Ribeiro <athoscr@fedoraproject.org> - 1.10.0-1
- Update version

* Wed Sep 20 2017 Athos Ribeiro <athoscr@fedoraproject.org> - 1.9.0-1
- Update version

* Wed Aug 02 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.8.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.8.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Mon Jun 26 2017 Athos Ribeiro <athoscr@fedoraproject.org> - 1.8.1-1
- Update version

* Mon Apr 03 2017 Athos Ribeiro <athoscr@fedoraproject.org> - 1.8.0-2
- Add go-toml dependency

* Mon Apr 03 2017 Athos Ribeiro <athoscr@fedoraproject.org> - 1.8.0-1
- Update version

* Thu Mar 16 2017 Athos Ribeiro <athoscr@fedoraproject.org> - 1.7.0-5
- Fix unit-test-devel subpackage dependencies

* Wed Mar 15 2017 Athos Ribeiro <athoscr@fedoraproject.org> - 1.7.0-4
- Change package name to go-i18n
- Include cvs information golang automatic tools can parse it
- Remove unnecessary conditional blocks
- Add macro for codegen binary

* Sun Mar 12 2017 Athos Ribeiro <athoscr@fedoraproject.org> - 1.7.0-3
- Include dist tag
- Provide shorter summary
- Remove empty conditional blocks
- Remove testdata .go files from -devel subpackage

* Fri Mar 03 2017 Athos Ribeiro <athoscr@fedoraproject.org> - 1.7.0-2
- Move test data to package path

* Sun Feb 26 2017 Athos Ribeiro <athoscr@fedoraproject.org> - 1.7.0-1
- Initial package
